import java.io.CharConversionException;
import java.io.UnsupportedEncodingException;

import com.ibm.as400.access.AS400Bin4;
import com.ibm.as400.access.AS400Text;
import com.ibm.as400.access.BinaryFieldDescription;
import com.ibm.as400.access.CharacterFieldDescription;
import com.ibm.as400.access.Record;
import com.ibm.as400.access.RecordFormat;
import com.ibm.broker.javacompute.MbJavaComputeNode;
import com.ibm.broker.plugin.MbBLOB;
import com.ibm.broker.plugin.MbElement;
import com.ibm.broker.plugin.MbException;
import com.ibm.broker.plugin.MbMessage;
import com.ibm.broker.plugin.MbMessageAssembly;
import com.ibm.broker.plugin.MbOutputTerminal;
import com.ibm.broker.plugin.MbUserException;

public class ISeriesDataQueueOut_BuildDataQueueMessage extends MbJavaComputeNode {

	public void evaluate(MbMessageAssembly inAssembly) throws MbException {
		MbOutputTerminal out = getOutputTerminal("out");

		MbMessage inMessage = inAssembly.getMessage();
		MbMessage outMessage = new MbMessage(inMessage);
		
		MbMessageAssembly outAssembly = null;

		// ----------------------------------------------------------
		// Add user code below
		try {
			BinaryFieldDescription customerNumber = new BinaryFieldDescription(new AS400Bin4(), "CUSTOMER_NUMBER");
			BinaryFieldDescription partNumber = new BinaryFieldDescription(new AS400Bin4(), "PART_NUMBER");
			CharacterFieldDescription partName = new CharacterFieldDescription(new AS400Text(20), "PART_NAME");
			BinaryFieldDescription quantity = new BinaryFieldDescription(new AS400Bin4(), "QUANTITY");

			// Build a record format and fill it with the base data types.
			RecordFormat dataFormat = new RecordFormat();
			dataFormat.addFieldDescription(customerNumber);
			dataFormat.addFieldDescription(partNumber);
			dataFormat.addFieldDescription(partName);
			dataFormat.addFieldDescription(quantity);

			Record data = new Record(dataFormat);

			// Set the values we received from the user into the record.
			data.setField("CUSTOMER_NUMBER", new Integer(1234));
			data.setField("PART_NUMBER", new Integer(5678));
			data.setField("QUANTITY", new Integer(1000));
			data.setField("PART_NAME", "Dummy");

			byte[] byteData = data.getContents();
			
			MbElement outRoot = outMessage.getRootElement();
			MbElement outParser = outRoot.createElementAsLastChild(MbBLOB.PARSER_NAME);
			outParser.createElementAsLastChild(MbElement.TYPE_NAME_VALUE, "BLOB", byteData);
			
			// Build the output message assembly before propagating the message.
			outAssembly = new MbMessageAssembly(inAssembly, outMessage);
		} catch (CharConversionException e) {
			throw new MbUserException(e, "evaluate", "ISeriesDataQueueOut_BuildDataQueueMessage", e.getMessage(), "Build dq message", null);
		} catch (UnsupportedEncodingException e) {
			throw new MbUserException(e, "evaluate", "ISeriesDataQueueOut_BuildDataQueueMessage", e.getMessage(), "Build dq message", null);
		}

		// End of user code
		// ----------------------------------------------------------

		// The following should only be changed
		// if not propagating message to the 'out' terminal

		out.propagate(outAssembly);
	}

}
