import java.io.UnsupportedEncodingException;

import com.ibm.as400.access.AS400Bin4;
import com.ibm.as400.access.AS400Text;
import com.ibm.as400.access.BinaryFieldDescription;
import com.ibm.as400.access.CharacterFieldDescription;
import com.ibm.as400.access.Record;
import com.ibm.as400.access.RecordFormat;
import com.ibm.broker.javacompute.MbJavaComputeNode;
import com.ibm.broker.plugin.*;


public class ISeriesKeyedDataQueueGet_JavaCompute extends MbJavaComputeNode {

	public void evaluate(MbMessageAssembly inAssembly) throws MbException {
		MbOutputTerminal out = getOutputTerminal("out");
		MbMessageAssembly outAssembly = null;
		
		try {
			MbMessage inMessage = inAssembly.getLocalEnvironment();
			MbMessage outMessage = new MbMessage()
			;
			MbElement record = inMessage.getRootElement().getLastChild();
			byte[] byteStream = record.toBitstream(MbBLOB.PARSER_NAME, null, null, 0, 0, 0);

			BinaryFieldDescription customerNumber = new BinaryFieldDescription(new AS400Bin4(), "CUSTOMER_NUMBER");
			BinaryFieldDescription partNumber = new BinaryFieldDescription(new AS400Bin4(), "PART_NUMBER");
			CharacterFieldDescription partName = new CharacterFieldDescription(new AS400Text(20), "PART_NAME");
			BinaryFieldDescription quantity = new BinaryFieldDescription(new AS400Bin4(), "QUANTITY");

			// Build a record format and fill it with the base data types.
			RecordFormat dataFormat = new RecordFormat();
			dataFormat.addFieldDescription(customerNumber);
			dataFormat.addFieldDescription(partNumber);
			dataFormat.addFieldDescription(partName);
			dataFormat.addFieldDescription(quantity);

			Record data = dataFormat.getNewRecord(byteStream);
			
			Integer customerNumberValue = (Integer) data.getField("CUSTOMER_NUMBER");
			Integer partNumberValue = (Integer) data.getField("PART_NUMBER");
			String partNameValue = ((String) data.getField("PART_NAME")).trim();
			Integer quantityValue = (Integer) data.getField("QUANTITY");
			
			MbElement outRoot = outMessage.getRootElement();
			MbElement outBody = outRoot.createElementAsLastChild(MbXMLNSC.PARSER_NAME);
			MbElement message = outBody.createElementAsLastChild(MbElement.TYPE_NAME, "Message", null);

			message.createElementAsLastChild(MbElement.TYPE_NAME, "CUSTOMER_NUMBER", customerNumberValue);
			message.createElementAsLastChild(MbElement.TYPE_NAME, "PART_NUMBER", partNumberValue);
			message.createElementAsLastChild(MbElement.TYPE_NAME, "PART_NAME", partNameValue);
			message.createElementAsLastChild(MbElement.TYPE_NAME, "QUANTITY", quantityValue);

			// Build the output message assembly before propagating the message.
			outAssembly = new MbMessageAssembly(inAssembly, outMessage);
 		} catch (UnsupportedEncodingException e) {
 			throw new MbUserException(e, "evaluate", "ISeriesKeyedDataQueueIn_JavaCompute", e.getMessage(), "Build xml from dq message", null);
		}

		out.propagate(outAssembly);
	}

}
